<?php

/**
* Title		: Aqua Resizer
* Description	: Resizes WordPress images on the fly
* Version	: 1.1.6 / ( 1.0.2 by OM)
* Author	: Syamil MJ
* Author URI	: http://aquagraphite.com
* License	: WTFPL - http://sam.zoy.org/wtfpl/
* Documentation	: https://github.com/sy4mil/Aqua-Resizer/
*
* @param	string $url - (required) must be uploaded using wp media uploader
* @param	int $width - (required)
* @param	int $height - (optional)
* @param	bool $crop - (optional) default to soft crop
* @param	bool $single - (optional) returns an array if false
* @uses		wp_upload_dir()
* @uses		image_resize_dimensions()
* @uses		wp_get_image_editor()
*
* @return str|array
*/

if(!defined('OMAQ_RESIZER')) {
	
	define('OMAQ_RESIZER', true);

	function omaq_resize( $url, $width, $height = null, $crop = null, $single = true ) {
		
		//validate inputs
		if(!$url OR !$width ) return false;
		
		//define upload path & dir
		$upload_info = wp_upload_dir();
		$upload_dir = $upload_info['basedir'];
		$upload_url = $upload_info['baseurl'];
		
		$url_nop=preg_replace('/^https?:/i','',$url);	
		$upload_url_nop=preg_replace('/^https?:/i','',$upload_url);
		
		//check if $img_url is local
		if(strpos( $url_nop, $upload_url_nop ) === false) return false;
		
		//define path of image
		$rel_path = str_replace( $upload_url_nop, '', $url_nop);
		$img_path = $upload_dir . $rel_path;
		
		//check if img path exists, and is an image indeed
		if( !file_exists($img_path) OR !getimagesize($img_path) ) return false;
		
		//get image info
		$info = pathinfo($img_path);
		$ext = $info['extension'];
		list($orig_w,$orig_h) = getimagesize($img_path);
		
		//get image size after cropping
		$dims = image_resize_dimensions($orig_w, $orig_h, $width, $height, $crop);
		$dst_w = $dims[4];
		$dst_h = $dims[5];
		
		//use this to check if cropped image already exists, so we can return that instead
		$suffix = "{$dst_w}x{$dst_h}";
		$dst_rel_path = str_replace( '.'.$ext, '', $rel_path);
		$destfilename = "{$upload_dir}{$dst_rel_path}-{$suffix}.{$ext}";
		
		if(!$dst_h) {
			//can't resize, so return original url
			$img_url = $url;
			$dst_w = $orig_w;
			$dst_h = $orig_h;
		}
		//else check if cache exists
		elseif(file_exists($destfilename) && getimagesize($destfilename)) {
			$img_url = "{$upload_url}{$dst_rel_path}-{$suffix}.{$ext}";
		} 
		//else, we resize the image and return the new resized image url
		else {
			
			// Note: This pre-3.5 fallback check will edited out in subsequent version
			if(function_exists('wp_get_image_editor')) {
				$editor = wp_get_image_editor($img_path);
				
				if ( is_wp_error( $editor ) || is_wp_error( $editor->resize( $width, $height, $crop ) ) )
					return false;
				
				$resized_img_path = $editor->save();

				if ( is_wp_error( $resized_img_path ) )
					return false;				
				
				$resized_img_path=$resized_img_path['path'];
				
			} else {
				$resized_img_path = $img_path; // Fallback foo
			}
			
			if(!is_wp_error($resized_img_path)) {
				$resized_rel_path = str_replace( $upload_dir, '', $resized_img_path);
				$img_url = $upload_url . $resized_rel_path;
			} else {
				return false;
			}
	
	
			// store generated sized into array
			$aq_files=get_option('_aq_resizer_generated_files', true);
			if(!is_array($aq_files))
				$aq_files=array();
			
			$aq_files_key=ltrim($rel_path,'/');
			$aq_files_value=ltrim($resized_rel_path,'/');
			
			if(!isset($aq_files[$aq_files_key]))
				$aq_files[$aq_files_key]=array();
				
			$aq_files[$aq_files_key][$aq_files_value]=1;
			
			update_option('_aq_resizer_generated_files', $aq_files);
	
		}
		
		
		//return the output
		if($single) {
			//str return
			$image = $img_url;
		} else {
			//array return
			$image = array (
				0 => $img_url,
				1 => $dst_w,
				2 => $dst_h
			);
		}
		
		return $image;
	}

	// remove generated by aq_resizer thumbnails on attachment deletion
	function omaq_delete_aq_resize_image($postid) {
	
		$aq_files=get_option('_aq_resizer_generated_files', true);
		if(!is_array($aq_files))
			return false;
	
		$uploadpath = wp_upload_dir();
	
		$meta=wp_get_attachment_metadata($postid);
		
		if(isset($meta['file']) && isset($aq_files[$meta['file']]) && is_array($aq_files[$meta['file']])) {
			foreach( $aq_files[$meta['file']] as $file => $v) {
				@ unlink( path_join($uploadpath['basedir'], $file) );
			}
			unset($aq_files[$meta['file']]);
		}
		
		update_option('_aq_resizer_generated_files', $aq_files);
		
	}
	if(!has_action('delete_attachment','omaq_delete_aq_resize_image'))
		add_action('delete_attachment','omaq_delete_aq_resize_image');

}